.. currentmodule:: sardana.macroserver.mscontainer

:mod:`~sardana.macroserver.mscontainer`
=======================================

.. automodule:: sardana.macroserver.mscontainer

.. rubric:: Functions

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`MSContainer`

MacroServer
------------

.. inheritance-diagram:: MSContainer
    :parts: 1
    
.. autoclass:: MSContainer
    :show-inheritance:
